autowisp.database.data_model.provenance.mount_access module — AutoWISP documentation

# autowisp.database.data_model.provenance.mount_access module

## Class Inheritance Diagram

Define the mount access dataset table for the pipeline

class autowisp.database.data_model.provenance.mount_access.MountAccess(**kwargs)

  Bases: `DataModelBase`

  The table dscribing the mount access

  id

    A unique identifier for each row.

  mount_id

    A unique identifier of the mount

  observer_id

    A unique identifier for the observer

  timestamp

    When record was last changed